# pyBabyMaker

[![build-status](https://travis-ci.com/umd-lhcb/pyBabyMaker.svg?build)](https://travis-ci.com/umd-lhcb/pyBabyMaker)
[![docs](https://readthedocs.org/projects/pybabymaker/badge/?version=latest)](https://pybabymaker.readthedocs.io/en/latest)
[![coverage](https://codecov.io/gh/umd-lhcb/pyBabyMaker/branch/master/graph/badge.svg)](https://codecov.io/gh/umd-lhcb/pyBabyMaker)
[![PyPI version](https://badge.fury.io/py/pyBabyMaker.svg)](https://badge.fury.io/py/pyBabyMaker)

Python babymaker (flat ntuple generation tool) library.
Please refer to [`readthedocs`](https://pybabymaker.readthedocs.io/en/latest) for detailed documentation.
